<?php

namespace Drupal\cookie_bot_protection\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Admin settings of the cookie bot protection.
 */
class SettingsForm extends ConfigFormBase {

  public const SETTINGS = 'cookie_bot_protection.settings';

  /**
   * {@inheritdoc}
   *
   * @return string[]|string
   *   The configuration names.
   */
  protected function getEditableConfigNames(): array|string {
    return [self::SETTINGS];
  }

  /**
   * {@inheritdoc}
   */
  public function getFormId(): string {
    return "cookie_bot_protection_configuration_form";
  }

  /**
   * Form constructor.
   *
   * @param mixed[] $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   *
   * @return mixed[]
   *   The form structure.
   */
  public function buildForm(array $form, FormStateInterface $form_state): array {
    $config = $this->config(self::SETTINGS);

    $form['url_protected_patterns'] = [
      '#type' => 'textarea',
      '#title' => $this->t('Url protected patterns'),
      '#description' => $this->t("One url pattern per line with allowed preg_match pattern without delimiters. Don't forget to exclude unwanted capture by a non-capturing group (?:pattern)"),
      '#default_value' => $config->get('url_protected_patterns'),
    ];

    $form['redirect_error_delay'] = [
      '#type' => 'number',
      '#title' => $this->t('Redirect error delay'),
      '#min' => 0,
      '#step' => 1,
      '#description' => $this->t('Delay to redirect to the page after a forbidden code due to missing cookie management or an url having a drupal_cbp_check query parameter.'),
      '#default_value' => $config->get('redirect_error_delay') ?? 5,
    ];

    $form['header_response_debug'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Information debug return into response header'),
      '#description' => $this->t('Information debug return into response header.'),
      '#default_value' => $config->get('header_response_debug') ?? 5,
    ];

    return parent::buildForm($form, $form_state);
  }

  /**
   * Form submission handler.
   *
   * @param mixed[] $form
   *   An associative array containing the structure of the form.
   * @param \Drupal\Core\Form\FormStateInterface $form_state
   *   The current state of the form.
   *
   * @return void
   *   Void
   */
  public function submitForm(array &$form, FormStateInterface $form_state): void {
    $this->config(static::SETTINGS)
      ->set('url_protected_patterns', $form_state->getValue('url_protected_patterns'))
      ->set('redirect_error_delay', $form_state->getValue('redirect_error_delay'))
      ->set('header_response_debug', $form_state->getValue('header_response_debug'))
      ->save();

    parent::submitForm($form, $form_state);
  }

}
